@@ -11,7 +11,7 @@ class Cfg(object):
     RESPONSE_MIDDLEWARES = []
     MIDDLEWARES = []
     CHARSET = 'utf-8'
-    POST_MAX_SIZE = 1024 * 1024 * 1  # максимальный размер пост-данных, None - не ограничивать
+    POST_MAX_SIZE = 1024 * 1024    # максимальный размер пост-данных, None - не ограничивать
     POST_MAX_MEMFILE = 1024 * 100  # максимальный размер POST-данных, загружаемый в память. Если больше, создаётся временный файл.
     ERROR_PAGES = {}
     TEMPLATE_CACHE_SIZE = 250
